diskstats

package
v0.0.0-...-2d83fc9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 26, 2017 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Overview

Package diskstats handles processing of IO statistics of each block device, /proc/diskstats. Instead of returning a Go struct, it returns JSON serialized bytes. A function to deserialize the JSON serialized bytes into a structs.DiskStats struct is provided.

Note: the package name is diskstats and not the final element of the import path (json).

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Deserialize

func Deserialize(p []byte) (*structs.DiskStats, error)

Deserialize takes some JSON serialized bytes and unmarshals them as structs.DiskStats.

func Get

func Get() (p []byte, err error)

Get returns information about current IO statistics of the block devices as JSON serialized bytes using the package's global Profiler.

func Marshal

func Marshal(st *structs.DiskStats) ([]byte, error)

Marshal is an alias for Serialize; uses the package's global Profiler.

func NewTicker

func NewTicker(d time.Duration) (joe.Tocker, error)

NewTicker returns a new Ticker containing a Data channel that delivers the data at intervals and an error channel that delivers any errors encountered. Stop the ticker to signal the ticker to stop running. Stopping the ticker does not close the Data channel; call Close to close both the ticker and the data channel.

func Serialize

func Serialize(st *structs.DiskStats) (p []byte, err error)

Serialize structs.DiskStats using JSON with the package's global Profiler.

func Unmarshal

func Unmarshal(p []byte) (*structs.DiskStats, error)

Unmarshal is an alias for Deserialize.

Types

type Profiler

type Profiler struct {
	*stats.Profiler
}

Profiler is used to process the /proc/diskstats file.

func NewProfiler

func NewProfiler() (prof *Profiler, err error)

Returns an initialized Profiler; ready to use.

func (*Profiler) Get

func (prof *Profiler) Get() (p []byte, err error)

Get returns information about current IO statistics of the block devices as JSON serialized bytes.

func (*Profiler) Marshal

func (prof *Profiler) Marshal(st *structs.DiskStats) ([]byte, error)

Marshal is an alias for Serialize.

func (*Profiler) Serialize

func (prof *Profiler) Serialize(st *structs.DiskStats) ([]byte, error)

Serialize structs.DiskStats using JSON.

type Ticker

type Ticker struct {
	*joe.Ticker
	Data chan []byte
	*Profiler
}

Ticker delivers the system's IO statistics of the block devices at intervals.

func (*Ticker) Close

func (t *Ticker) Close()

Close closes the ticker resources.

func (*Ticker) Run

func (t *Ticker) Run()

Run runs the ticker.

Jump to