Documentation
¶
Overview ¶
Package version gets the kernel and version information from the /proc/version file.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Kernel ¶
type Kernel struct {
OS string `json:"os"`
Version string `json:"version"`
CompileUser string `json:"compile_user"`
GCC string `json:"gcc"`
OSGCC string `json:"os_gcc"`
Type string `json:"type"`
CompileDate string `json:"compile_date"`
Arch string `json:"arch"`
}
Kernel holds information about the kernel and version.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package version gets the kernel and version information from the /proc/version file.
|
Package version gets the kernel and version information from the /proc/version file. |
|
Package version gets the kernel and version information from the /proc/version file.
|
Package version gets the kernel and version information from the /proc/version file. |
Click to show internal directories.
Click to hide internal directories.