Documentation
¶
Overview ¶
Package version gets the kernel and version information from the /proc/version file. Instead of returning a Go struct, it returns Flatbuffer serialized bytes. A function to deserialize the Flatbuffer serialized bytes into a version.Kernel struct is provided.
Note: the package name is version and not the final element of the import path (flat).
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Deserialize ¶
Deserialize takes some Flatbuffer serialized bytes and deserializes them as version.Kernel.
Types ¶
Click to show internal directories.
Click to hide internal directories.