Documentation
¶
Overview ¶
Package diskstats handles processing of IO statistics of each block device, /proc/diskstats. Instead of returning a Go struct, it returns JSON serialized bytes. A function to deserialize the JSON serialized bytes into a structs.DiskStats struct is provided.
Note: the package name is diskstats and not the final element of the import path (json).
Index ¶
- func Deserialize(p []byte) (*structs.DiskStats, error)
- func Get() (p []byte, err error)
- func Marshal(st *structs.DiskStats) ([]byte, error)
- func NewTicker(d time.Duration) (joe.Tocker, error)
- func Serialize(st *structs.DiskStats) (p []byte, err error)
- func Unmarshal(p []byte) (*structs.DiskStats, error)
- type Profiler
- type Ticker
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Deserialize ¶
Deserialize takes some JSON serialized bytes and unmarshals them as structs.DiskStats.
func Get ¶
Get returns information about current IO statistics of the block devices as JSON serialized bytes using the package's global Profiler.
func NewTicker ¶
NewTicker returns a new Ticker containing a Data channel that delivers the data at intervals and an error channel that delivers any errors encountered. Stop the ticker to signal the ticker to stop running. Stopping the ticker does not close the Data channel; call Close to close both the ticker and the data channel.
Types ¶
type Profiler ¶
Profiler is used to process the /proc/diskstats file.
func NewProfiler ¶
Returns an initialized Profiler; ready to use.
func (*Profiler) Get ¶
Get returns information about current IO statistics of the block devices as JSON serialized bytes.